Sutekh Tutorial

# Sutekh Tutorial (for Sutekh 2.2.1)

## Contents

1. The Initial Layout
2. Working with cards
3. Manipulating Panes
4. Managing Card Sets
5. Filtering
6. Profiles
7. Useful Tips

## The Initial Layout

When you run Sutekh for the first time, it will display the following four panes:

- Full Card List
- Card Text
- Card Set List
- My Collection

On subsequent runs, Sutekh will read the list of panes to display from it’s config file. You can determine which panes are shown either by explicitly saving the layout using Save current pane set in File->Preferences, or by setting the Save Pane Set on Exit option save the configuration.

### The Full card list

Sutekh maintains a list of all the cards published by the V:EKN as the Full Card List. It lists the cards and the expansions in which each card has appeared.

To make vampires with the same name that occur in multiple groups easier to work with, Sutekh appends (Group X) to the names of all crypt cards. This can be hidden for those cards which only occur in one group via the preferences menu.

### Card Text

This pane displays information about the currently selected card.

### Card Sets

In Sutekh, collections of cards are card sets. Card Sets can either be stand-alone or subsets of other card sets. This pane lists all the card sets which have been created. Initially, only a card set called My Collection is created, to store the details of your card collection.

### My Collection

This card set will store the details of your card collection.

## Working with Cards

### Adding cards to a card set

Card Sets are by default not editable. You can change this property by toggling the Card Set is Editable menu entry in the Edit Menu of the pane. Before adding cards to a card set, ensure that it is editable.

For convenience, when a card set is first created, it is opened as editable.

You can add cards by dragging them from the Full Card List to the pane of the card set. You can also use the copy and paste options from the edit menu. If you copy multiple cards, you will add a single copy of each distinct selected card to the destination set. If you have selected multiple copies of the same card, only one copy will be added.

If a card set is editable, + and – buttons are displayed next to the card names. You can use these to increase or decrease the number of copies of a card that are present in the set.

You can also change this value using the keyboard. You can type + and – to increment or decrement the count of a selected card, or type a number from one to nine to set the value directly.

You can also copy and paste or drag and drop cards from other card sets. If you do this, all copies of each selected card which are in the source set will be added to the destination set.

You can select all the cards in a card set using either <Ctrl>-A or <Ctrl>-/, and unselect all selected cards using <Ctrl>-<Shift>-A.

### Removing cards

You can remove cards from a card set by using the – button shown in the card set pane next to the card name, by using the keyboard shortcuts to change the number of cards, or by selecting cards and using the Delete selection option in the Edit menu.

## Manipulating Panes

The Sutekh user interface consists of panes. The number of panes and the layout is entirely configurable.

You can add panes using the Add Pane Menu, and replace the contents of the currently selected pane using the Replace Pane Menu. You can also add new blank panes by splitting the current pane; either into two panes next to each other, or into two panes stacked one above the other. You can swap two panes by dragging one onto the other.

When you double-click on an entry in the Card Set list, the card set will be opened in a new pane added on the right. You can also open a card set in a specific pane by dragging the card set name from the Card Set list to the desired pane.

If the Save Pane Set on Exit option in the File->Preferences menu is set, Sutekh will save the current layout when you exit, and restore it on startup. You can also save the current layout using the Save Current Pane Set option.

You can remove panes from the list using the Pane Actions->Remove current pane menu option (or the associated keyboard shortcut). If you delete a card set, its pane will be closed automatically.

## Managing Card Sets

### Creating a new card set

You can create a new card set in the Card Set List using the Create New Card Set option in the Actions menu. The name is required, and must be unique. You can specify that a card set is a subset of a another card set, by selecting an existing card set to be it’s parent, or you can not select a parent, in which case it will be a stand-alone card set.

For each card set, you can add the author information, a description and annotations about the card set. Both the description and annotations entries are free form text entries, and can be formatted as desired.

### Renaming a card set.

You can rename a card set using the Edit Card Set Properties option in the Actions menu of the card set list pane. You can also rename an open card set using the Edit Card Set Properties option in the Actions Menu of the card set pane.

### Changing the parent of a card set.

You can change the parent of a card set by using the Edit Card Set Properties option in the Actions Menu, or by dragging the selected card set onto its new parent in the card set list pane. To change a card set to have no parent, you have to use the Edit Card Set Properties option and unselect the existing parent using either <Ctrl>-<space> or <Ctrl>-<left button>.

### Deleting a card set

You can delete a card set using the Delete card set option in the Actions menu of the card set list pane. You can also delete an open card set using the Delete card set option in the Actions menu of the card set pane.

### In Use Card sets

Card sets can be marked or unmarked as In Use. In Use card sets are considered to be those which are currently active. Display modes which show child card sets only consider child cards sets which are marked as In Use.

### The Different card display and count modes

Sutekh has several settings which control which cards are displayed in a card set pane, and what information about the cards is displayed.

The display of cards will also be affected by any filters that are applied.

#### The Cards to Show options

This setting controls which cards are displayed.

The default mode shows only those cards that belong to the actual card set.

Show All Cards shows the entire list of cards. This mode is often useful when you are entering cards into a card set for the first time.

Show all cards in parent card set shows the combination of the cards in this card set and all the cards in the parent card set. It is useful for seeing which cards are available to be added to a deck.

Show all cards in child card sets shows all cards that belong to the In Use children of this card set in addition to the cards in this card set.

#### The Display Mode options

This setting controls what information is displayed below the card name.

Show Expansions shows the expansions of the cards, and a card count for each expansion. This is the default.

Show No Children disables the display of additional information below the card name.

Show Child Card Sets shows the allocation of cards to the In Use children of the current card set.

Show Expansions and Child Card Sets shows the expansion information as well as the child card set breakdown for each expansion.

Show Child Card Sets and Expansions is the reverse of Show Expansions and Child Card Sets. It shows the child card sets and the expansion breakdown for each child card set.

#### The Parent Card Count options

If the card set is the child of another card set, you can also display information about the parent card set.

Show Parent Count shows the count of the same card in the parent card set. This is the default.

Don’t show parent card counts disables the column with the parent count.

Show difference between Parent Count and this card set shows the difference between the parent count and the count for this card set.

Show difference between Parent Count and card sets in use shows the difference between the parent card set count and the total count in all In Use card sets. If this card set is not In Use, then the number of cards in this set does not influence this number.

## Filtering

Sutekh has a very powerful filtering model, which allows you to perform quite complex queries on the card database.

### The Basic filters

There are several basic filters available, such as Clan, Discipline, Card Text etc..

Most of these filters allow only a limited range of options, which you can select from the list. The Clan filter, for example, only accepts the clans listed in the database as input. You can select multiple clans, and the filter will match a card if it matches any of the selected clans.

Other filters, such as the Card Text filter, require you to enter a string. The filter will match any card with card text that contains this string. The % and _ characters can be used as wildcards: % will match any number of letters, and _ will match exactly one.

The Card Sets In Use filter takes no input.

The Card Count filter requires you to input a list of card counts and a list of card sets.

### Combing basic filters

You can combine these basic filters to create more complex queries by placing filters inside a filter group.

Multiple filters can be combined according to one of the following rules:

All of requires all of the included filters to be satisfied simultaneously. It is useful for finding cards which require a discipline and a given cost, for example.

Any of requires that at least one of the included filters is satisfied.

Not All of requires that at least one of the included filters is not satisfied. The difference between Not All of and Any of is that Any of will include the results of any cards that match all of the filters, while Not All of will exclude those, but return cards that satisfy none of the filters.

None of requires that none of the included filters be satisfied.

A Filter Group can be added to an existing Filter Group, which allows combinations to be nested. Thus an All of filter can include Any of or None of filters below it, which allows for extremely complex queries to be constructed.

For example, to find all cards that require either Follower of Set or Serpentis, but not both, you could construct the following filter:

An Any of filter, which includes two All of sub-filters. Each sub-filter includes the Clan and Discipline basic filters, and one is set to match Followers of Set and NOT Serpentis while the other is set to match NOT Followers of Set and Serpentis.

Once you have constructed a filter, you can name and save it, and load it again later.

### Filtering the Card Set List

You can also filter the card set list. The basic filters available here are:

- The card set name
- The card set author
- The card set description
- The name of the parent card set
- Text in the annotations of the card set
- All card sets marked in use

You can also combine these filters, and create queries such as All card sets in use where the card set name includes Nosferatu.

When Sutekh displays card sets which match a filter, all the direct ancestors of those sets are also displayed even if they do not match the filter themselves, so that the matching sets can be shown in their correct position in the hierarchy.

## Profiles

### Overview

Sutekh has a lot of options for customising the way a card set is displayed. These options are controlled by the profile feature. Profiles are available for individual card sets, the WW cardlist and the card set list.

You can create several profiles and switch between them easily using the Cardset profile, Cardlist profile or CardSet List profile menus as required. Profiles are saved and will be re-applied one the next run.

In addition, for card sets, there’s the Pane profile menu. You can have multiple copies of a card set open at the same time. The cardset profile choice applies to all open copies of the same card set, while the pane profile overrides that for a specific pane.

There’s also the local profile, which makes changes that aren’t saved in the config file. This is useful for making quick changes to the local view that you don’t want to keep or apply to other panes using the same profile.

### Group by

The Group by option controls the top level division used to arrange the cards. By default, this is the CardType grouping, which groups cards together by their card types (Vampire, Master, Action, etc.). Other groupings include: Clan or Creed, to arrange on clans, Group, to arrange by the vampire grouping and Cost to arrange by card cost.

### Extra Columns

The Extra Columns option allows you to specify additional information about the cards to be displayed in the pane. These extra columns can also be used to sort the card set, which can be useful with columns such as Cost or Capacity.

### Filter

The Filter option in the profile allows you to specify a saved filter that is always applied when this profile is used. This is can be used to create specify views of a card set, such as showing all vampires grouped by clan or so forth.

## Useful Tips

### Entering card sets

The different display modes are often useful for entering a card set quickly. Start with with Show all cards or Show cards in parent card set and then increment the cards which you wish to add to the current card set. You can also use the Card Set from Filter option to create a card set.

When you import card sets from other formats, the expansion information may be missing, in which case these cards will be imported without an expansion. If you know that all the imported cards are from the same expansion — for example, if the card set is a starter deck — you can use the Set selection to single expansion option from the Actions menu to set all the cards to the correct expansion quickly.

### Search for cards and card sets

While it quite easy to use filters to restrict the cards or card sets shown, to find a specific card, the search dialog is often faster.

The search dialog can be popped by either using the Edit->Search menu option, the <Ctrl>-F shortcut, or by typing directly into the list view.

The dialog can be hidden by either pressing the Escape key, the Enter key, or by clicking outside the search dialog. Note that, to prevent unexpected side-effects, while the search dialog is shown, clicking will only hide the dialog and not effect any else.

The search looks to match names starting with the typed text. When multiple cards match, you can easily move between them by using the up or down keys while the search dialog is visible.

The Use “path of …, the” name display preference controls how cards that start with “The”, “An” or “A” are displayed. If set, the prefix is displayed at the end. This also effects how the card name search matches the cards.

### Opening multiple copies of the card set

It’s possible to open multiple copies of a given card set. This can be useful for displaying different sets of extra columns for different filters, and so forth. Open another copy of the card set either by dragging the card set name from the card set list onto a different pane, or by double clicking the card set name.

### Organising card sets

It’s often useful to keep a record of card sets that are related, but aren’t strictly subsets of another card set, such as card orders or particular deck ideas. One common approach is to use empty card sets to act as card set holders which group logically related card sets together.

### Tracking the history of a card set

The Take a snapshot of this card set option can be used to keep a history of how a card set evolves. Snapshots are children of the current card set, so the different view modes can be used and the Compare with another Card Set can be used to see how a card set has changed between different versions.

### Separating crypt and library views.

It is sometimes useful to work with the crypt and library of a card set separately, showing different information about both. The easiest way is to open two copies of the card set, and use different pane profiles for each. The crypt profile should include a filter that selects crypt cards and display the desired extra information (Clan, Capacity, etc.), while the library profile should filter on non-crypt cards and show columns such as cost or disciplines.

The Sutekh Manual